@@ -21,7 +21,7 @@ struct TableHead {
 	char last_full;
 	char endian;
 	int KeyS;		/* number of keys needed */
-	int MaxPress;		/* Max len of keystroke  ar30:4  changjei:5 */
+	int MaxPress;		/* Max len of keystroke  array30:4  cj:5 */
 	int M_DUP_SEL;		/* how many keys used to select */
 	int DefC;		/* Defined characters */
 };
